pub trait RequestSign {
// Required methods
fn sign<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Send
where Self: Sized;
fn proof<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Send
where Self: Sized;
fn verify_sign<V: VerifierKey>(
&self,
key: &V,
) -> impl Future<Output = Result<(), VerificationError>> + Send
where Self: Sized + Sync;
}Required Methods
Sourcefn sign<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Sendwhere
Self: Sized,
fn sign<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Sendwhere
Self: Sized,
Write the signature to the HTTP header, Signature.
If you want to write to Authorization header, consider using RequestSign::proof.
Sourcefn proof<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Sendwhere
Self: Sized,
fn proof<S: SignerKey>(
self,
key: &S,
params: &SignatureParams,
) -> impl Future<Output = Result<Self, SignError>> + Sendwhere
Self: Sized,
Write the signature to the HTTP header, Authorization.
If you want to write to Signature header, consider using RequestSign::sign.
fn verify_sign<V: VerifierKey>( &self, key: &V, ) -> impl Future<Output = Result<(), VerificationError>> + Send
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".